@@ -2,7 +2,7 @@
 # vim: ai ts=4 sts=4 et sw=4
 
 
-from django.conf.urls.defaults import *
+from django.conf.urls import patterns, url
 from . import views
 
 
