@@ -1,4 +1,4 @@
-from django.conf.urls.defaults import *
+from django.conf.urls import patterns, include, url
 from django.contrib import admin
 
 admin.autodiscover()
@@ -17,7 +17,6 @@ urlpatterns = patterns('',
     url(r'^$', 'rapidsms.views.dashboard', name='rapidsms-dashboard'),
 
     # RapidSMS contrib app URLs
-    (r'^export/', include('rapidsms.contrib.export.urls')),
     url(r'^httptester/$',
         'rapidsms.contrib.httptester.views.generate_identity',
         {'backend_name': 'message_tester'}, name='httptester-index'),
@@ -26,5 +25,7 @@ urlpatterns = patterns('',
     (r'^messagelog/', include('rapidsms.contrib.messagelog.urls')),
     (r'^messaging/', include('rapidsms.contrib.messaging.urls')),
     (r'^registration/', include('rapidsms.contrib.registration.urls')),
-    (r'^scheduler/', include('rapidsms.contrib.scheduler.urls')),
+
+    # Third party URLs
+    (r'^selectable/', include('selectable.urls')),
 )
